@@ -132,18 +132,21 @@ class ZbxCommon(object):
         self.modules = {'zmq': 'pyzmq==19.0.2', 'pymysql': 'PyMySQL==0.9.2', 'kafka': 'kafka==1.3.5',
                         'redis': 'redis==3.5.3', 'yaml': 'PyYAML==5.3.1', 'pyquery': 'pyquery==1.4.3',
                         'elasticsearch': 'elasticsearch==7.17.4', 'flask': 'Flask==1.0.2',
-                        'requests': 'requests==2.25.0'}
+                        'requests': 'requests==2.25.0', 'pymongo': 'pymongo==3.12.3'}
         if PY3:
             self.modules['kafka'] = 'kafka-python==2.0.2'
             self.modules['zmq'] = 'pyzmq==23.2.0'
             self.modules['flask'] = 'Flask==2.0.1'
             self.modules['pymysql'] = 'PyMySQL==1.0.2'
             self.modules['elasticsearch'] = 'elasticsearch==8.3.1'
+            self.modules['pymongo'] = 'pymongo==4.2.0'
+
         if len(sys.argv) == 2 and len(sys.argv[1]) == 36:
             self.get_param('')
 
     def gen_requirements(self, path=''):
         mods = []
+        install_mods = []
         for k, v in self.modules.items():
             mods.append(v)
         if path != '':
@@ -152,10 +155,11 @@ class ZbxCommon(object):
         else:
             if PY3:
                 for m in mods:
-                    print('pip3 install %s' % (m))
+                    install_mods.append('pip3 install %s' % (m))
             else:
                 for m in mods:
-                    print('pip install %s' % (m))
+                    install_mods.append('pip install %s' % (m))
+        return "\n".join(install_mods)
 
     def init_log(self):
         pass
@@ -923,6 +927,13 @@ class ZbxCommon(object):
         conn.row_factory = dict_factory
         return conn
 
+    def get_sqlite_tables(self, conn):
+        rows = self.sqlite_query(conn, "SELECT name FROM sqlite_master WHERE type='table'")
+        tables = []
+        for row in rows:
+            tables.append(row['name'])
+        return tables
+
     def sqlite_query(self, connection, sql, *args):
         cursor = connection.cursor()
         sql = str(sql).strip()
@@ -978,21 +989,21 @@ class ZbxCommon(object):
             else:
                 return cursor.execute(sql, args)
 
-    def _safe_dict(self, data):
+    def _safe_dict(self, data, db_type='mysql'):
         data = dict(data)
         for k, v in data.items():
-            data[k] = self._safe_value(v)
+            data[k] = self._safe_value(v, db_type)
         return data
 
-    def _safe_list(self, data):
+    def _safe_list(self, data, db_type='mysql'):
         if not isinstance(data, list):
             return data
         data = list(data)
         for i, v in enumerate(data):
             if type(v) == dict:
-                data[i] = self.mysql_safe_dict(v)
+                data[i] = self._safe_dict(v, db_type)
             else:
-                data[i] = self._safe_value(v)
+                data[i] = self._safe_value(v, db_type)
 
     def mysql_safe_value(self, v):
         if isinstance(v, list):
@@ -1001,16 +1012,20 @@ class ZbxCommon(object):
             return self._safe_dict(v)
         return self._safe_value(v)
 
-    def _safe_value(self, v):
+    def _safe_value(self, v, db_type='mysql'):
         if type(v) == int or type(v) == float:
             return str(v)
         if v is None:
             return 'NULL'
-        v = str(v).replace('\\', '\\\\').replace("'", "\\'")
-        v = v.replace("\n", "\\n").replace('"', '\\"')
+        if db_type == 'sqlite3' or db_type == 'sqlite':
+            v = str(v).replace('\\', '\\\\').replace("'", "''")
+            v = v.replace("\n", "\\n").replace('"', '\\"')
+        else:
+            v = str(v).replace('\\', '\\\\').replace("'", "\\'")
+            v = v.replace("\n", "\\n").replace('"', '\\"')
         return v
 
-    def gen_update_sql(self, table_name, dict_data, where_dict=None):
+    def gen_update_sql(self, table_name, dict_data, where_dict=None, db_type='mysql'):
         vs = []
         dict_data = dict(dict_data)
         where = ''
@@ -1023,15 +1038,15 @@ class ZbxCommon(object):
             ws = []
             where_dict = dict(where_dict)
             for k, v in where_dict.items():
-                ws.append("`{k}`='{v}'".format(k=k, v=self._safe_value(v)))
+                ws.append("`{k}`='{v}'".format(k=k, v=self._safe_value(v, db_type)))
                 where = ' WHERE {where}'.format(where=' AND '.join(ws))
         for k, v in dict_data.items():
             vs.append("`{k}`='{v}'".format(k=k, v=v))
-        sql = '''UPDATE `{table_name}` SET {fields} {where}'''.format(table_name=table_name,
-                                                                      fields=','.join(vs), where=where)
+        sql = '''UPDATE `{table_name}` SET {fields} {where};'''.format(table_name=table_name,
+                                                                       fields=','.join(vs), where=where)
         return sql
 
-    def gen_insert_sql(self, table_name, list_data):
+    def gen_insert_sql(self, table_name, list_data, batch_row_max=500, db_type='mysql'):
         row = {}
         if type(list_data) != list:
             self.log.error("table_data is not list,name: {table_name}".format(table_name=table_name))
@@ -1041,7 +1056,10 @@ class ZbxCommon(object):
         fields = list(row.keys())
         # map(lambda x:'`%s`'%(x),fields)
         rows = []
+        sqls = []
+        i = 0
         for row in list_data:
+            i = i + 1
             data = []
             for fn in fields:
                 if row[fn] is None:
@@ -1049,17 +1067,34 @@ class ZbxCommon(object):
                 elif type(row[fn]) == int or type(row[fn]) == float:
                     data.append(str(row[fn]))
                 else:
-                    s = str(row[fn]).replace('\\', '\\\\').replace("'", "\\'")
-                    s = s.replace("\n", "\\n").replace('"', '\\"')
-                    data.append("'%s'" % (s))
+                    if db_type == 'sqlite3' or db_type == 'sqlite':
+                        s = str(row[fn]).replace('\\', '\\\\').replace("'", "''")
+                        s = s.replace("\n", "\\n").replace('"', '\\"')
+                        data.append("'%s'" % (s))
+                    else:
+                        s = str(row[fn]).replace('\\', '\\\\').replace("'", "\\'")
+                        s = s.replace("\n", "\\n").replace('"', '\\"')
+                        data.append("'%s'" % (s))
             rows.append("\t(" + ','.join(data) + ')')
-        fields = list(map(lambda x: '`%s`' % (x), fields))
-        fields_str = ','.join(list(fields))
+            if i % batch_row_max == 0:
+                fields2 = list(map(lambda x: '`%s`' % (x), fields))
+                fields_str = ','.join(list(fields2))
+                data_str = ",\n".join(rows)
+                sqls.append(
+                    "INSERT INTO {table_name} ({fields_str}) \nVALUES\n{data_str};".format(table_name=table_name,
+                                                                                           fields_str=fields_str,
+                                                                                           data_str=data_str))
+                rows = []
+        fields2 = list(map(lambda x: '`%s`' % (x), fields))
+        fields_str = ','.join(list(fields2))
         data_str = ",\n".join(rows)
         sql = "INSERT INTO {table_name} ({fields_str}) \nVALUES\n{data_str};".format(table_name=table_name,
                                                                                      fields_str=fields_str,
                                                                                      data_str=data_str)
-        return sql
+
+        if len(rows) > 0:
+            sqls.append(sql)
+        return "\n".join(sqls)
 
     def get_mysql_tables(self, conn):
         tables = []
@@ -1068,21 +1103,118 @@ class ZbxCommon(object):
                 tables.append(v)
         return tables
 
-    def dump_mysql_ddl(self, conn, dir='', tables=[]):
+    def get_mysql_databases(self, conn):
+        databases = []
+        for i in self.mysql_query(conn, "show databases"):
+            for k, v in i.items():
+                databases.append(v)
+        return databases
+
+    def get_mysql_current_database(self, conn):
+        return self.mysql_query(conn, "select database()")[0]['database()']
+
+    def dump_sqlite_ddl(self, conn, dir='', tables=[]):
         tables_info = []
         infos = []
         if len(tables) == 0:
-            tables = self.get_mysql_tables(conn)
+            tables = self.get_sqlite_tables(conn)
         for table in tables:
-            info = self.mysql_query(conn, "show create table `{table}`".format(table=table))
+            info = self.sqlite_query(conn, '''
+    SELECT sql 
+FROM sqlite_schema 
+WHERE name = '{table}';'''.format(table=table))
+            info[0]['table'] = table
             tables_info.append(info[0])
-            infos.append(info[0]['Create Table'] + ";")
+            infos.append(info[0]['sql'] + ";")
         if dir != "":
             with open("{dir}/ddl.txt".format(dir=dir), 'w+') as fp:
                 fp.write("\n\n\n".join(infos))
         return tables_info
 
-    def dump_mysql_data(self, conn, dir='', limit=10, tables=[],overwrite=False):
+    def dump_mysql_ddl(self, conn, dir='', tables=[], with_database=False):
+        tables_info = []
+        infos = []
+        if with_database:
+            database = self.get_mysql_current_database(conn)
+            infos.append(
+                "CREATE DATABASE IF NOT EXISTS `{database}` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;".format(
+                    database=database))
+            infos.append("USE `{database}`;".format(database=database))
+        if len(tables) == 0:
+            tables = self.get_mysql_tables(conn)
+        for table in tables:
+            info = self.mysql_query(conn, "show create table `{table}`".format(table=table))
+            tables_info.append(info[0])
+            infos.append(re.sub(r'AUTO_INCREMENT\s*=\s*\d+', '', info[0]['Create Table'], 1, re.IGNORECASE) + ";")
+        if dir != "":
+            with open("{dir}/ddl.txt".format(dir=dir), 'w+') as fp:
+                fp.write("\n\n\n".join(infos))
+        return tables_info
+
+    def dump_mysql_update_dml(self, conn, dir='', tables=[], overwrite=True):
+        # conn = self.get_mysql_connection(dsn)
+        data_map = {}
+        if len(tables) == 0:
+            tables = self.get_mysql_tables(conn)
+            if overwrite and dir != '':
+                for table in tables:
+                    fpath = '{dir}/{table}.sql'.format(dir=dir, table=table)
+                    with open(fpath, 'w+') as fp:
+                        fp.write('')
+        for table in tables:
+            sql = 'select * from `{table}`'.format(table=table)
+            table_data = self.mysql_query(conn, sql)
+            if len(table_data) == 0:
+                continue
+            fpath = '{dir}/{table}.sql'.format(dir=dir, table=table)
+            for dict_data in table_data:
+                sql_str = self.gen_update_sql(table, dict_data)
+                if dir == '':
+                    if table in data_map:
+                        data_map[table].appen(sql_str + "\n")
+                    else:
+                        data_map[table] = []
+                        data_map[table].append(sql_str)
+                if dir != '':
+                    if not os.path.exists(fpath) or overwrite:
+                        with open(fpath, 'a') as fp:
+                            fp.write(sql_str + "\n")
+                            self.log.info('gen table {table}'.format(table=table))
+                    else:
+                        self.log.warn('skip table {table}'.format(table=table))
+            else:
+                self.log.error('dir is null')
+        return data_map
+
+    def dump_sqlite_data(self, conn, dir='', limit=10, tables=[], overwrite=False):
+        # conn = self.get_mysql_connection(dsn)
+        data_map = {}
+        if len(tables) == 0:
+            tables = self.get_sqlite_tables(conn)
+        for table in tables:
+            if limit > 0:
+                sql = 'select * from `{table}` limit {limit}'.format(table=table, limit=limit)
+            else:
+                sql = 'select * from `{table}`'.format(table=table, limit=limit)
+            table_data = self.sqlite_query(conn, sql)
+            if len(table_data) == 0:
+                continue
+            fpath = '{dir}/{table}.sql'.format(dir=dir, table=table)
+            sql_str = self.gen_insert_sql(table, table_data, db_type='sqlite')
+            if dir == '':
+                data_map[table] = sql_str
+            if dir != '':
+                if not os.path.exists(fpath) or overwrite:
+                    with open(fpath, 'w+') as fp:
+                        fp.write(sql_str)
+                        self.log.info('gen table {table}'.format(table=table))
+                else:
+                    self.log.warn('skip table {table}'.format(table=table))
+            else:
+                self.log.error('dir is null')
+        return data_map
+
+    def dump_mysql_data(self, conn, dir='', limit=10, tables=[], overwrite=False):
         # conn = self.get_mysql_connection(dsn)
         data_map = {}
         if len(tables) == 0:
@@ -1093,6 +1225,8 @@ class ZbxCommon(object):
             else:
                 sql = 'select * from `{table}`'.format(table=table, limit=limit)
             table_data = self.mysql_query(conn, sql)
+            if len(table_data) == 0:
+                continue
             fpath = '{dir}/{table}.sql'.format(dir=dir, table=table)
             sql_str = self.gen_insert_sql(table, table_data)
             if dir == '':
@@ -1127,6 +1261,11 @@ class ZbxCommon(object):
         import pymysql
         return pymysql
 
+    @property
+    def pymongo(self):
+        import pymongo
+        return pymongo
+
     @property
     def flask(self):
         import flask
@@ -1851,7 +1990,7 @@ def __check_module():
             try:
                 __import__(m)
             except Exception as err:
-                logger.warn('No module named: %s' % (m))
+                logger.warning('No module named: %s' % (m))
 
 
 __check_module()
