@@ -240,21 +240,84 @@ Exit:4->5
 
 
 
-
-from transitions import Transition,Machine
+#
+# from transitions import Transition,Machine
+#
+#
+# data=cli.parse_fsm_flow(flow)
+#
+# class Matter(object):
+#     pass
+# model = Matter()
+#
+# machine = Machine(model=model, **cli.parse_fsm_flow(flow), initial='New')
+#
+# # machine.set_state('Exit')
+# for i in range(1,10):
+#     print(model.state)
+#     print(model.Admitted())
+#     print(model.Dispatch())
 
 
-data=cli.parse_fsm_flow(flow)
+# dsn = 'mysq://root:mock@127.0.0.1:63307/mock'
+# # d = '/Users/junqiang.zhang/repo/go/hr-api/mock/db'
+# d='/tmp/test'
+# conn = cli.get_mysql_connection(dsn)
+# tables=['audit_log_tab']
+# # tables.remove('audit_log_tab')
+# # cli.dump_mysql_data(conn, dir=d, limit=0, overwrite=True,tables=tables)
+#
+# cli.dump_mysql_update_dml(conn,dir=d)
 
-class Matter(object):
-    pass
-model = Matter()
 
-machine = Machine(model=model, **cli.parse_fsm_flow(flow), initial='New')
+# conn=cli.get_sqlite_connection(":memory:")
+#
+# cli.sqlite_query(conn,'''
+# CREATE TABLE COMPANY(
+#    ID INT PRIMARY KEY     NOT NULL,
+#    NAME           TEXT    NOT NULL,
+#    AGE            INT     NOT NULL,
+#    ADDRESS        CHAR(50),
+#    SALARY         REAL
+# );
+# ''')
+#
+# cli.sqlite_query(conn,'''
+# CREATE TABLE abc(
+#    ID INT PRIMARY KEY     NOT NULL,
+#    NAME           TEXT    NOT NULL,
+#    AGE            INT     NOT NULL,
+#    ADDRESS        CHAR(50),
+#    SALARY         REAL
+# );
+# ''')
+#
+# sql='''
+# INSERT INTO COMPANY (`ID`,`NAME`,`AGE`,`ADDRESS`,`SALARY`)
+# VALUES
+# (1,'jqzh''ang',30,NULL,NULL),
+# (2,'hello',35,NULL,NULL);'''
+# cli.sqlite_query(conn,sql)
+# sql= cli.dump_sqlite_data(conn)['COMPANY']
+#
+# cli.sqlite_query(conn,'delete from COMPANY')
+#
+#
+#
+#
+# cli.sqlite_query(conn,sql)
+#
+#
+# print(cli.dump_sqlite_data(conn)['COMPANY'])
+
+
+# cli.dump_sqlite_data(conn,'/tmp/test')
+
+dsn = 'mysql://sz_sc_test2:6vJaoy5HHiPP0ms_sUnO@master.shopee_sls.mysql.cloud.test.shopee.io:6606/shopee_ssc_hr_db'
+dsn='mysql://root:mock@127.0.0.1:63307/mock'
+
+conn = cli.get_mysql_connection(dsn)
+
+print(cli.dump_mysql_ddl(conn,dir='./'))
 
-# machine.set_state('Exit')
-for i in range(1,10):
-    print(model.state)
-    print(model.Admitted())
-    print(model.Dispatch())
 
